==> haskell-gauge-0.2.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gauge.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gauge
version: 0.2.1
id: gauge-0.2.1-3WbhqotitsoJYtBZKedikn
key: gauge-0.2.1-3WbhqotitsoJYtBZKedikn
license: BSD3
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-gauge
synopsis: small framework for performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Gauge Gauge.Analysis Gauge.Benchmark Gauge.Main Gauge.Main.Options
hidden-modules: Gauge.IO.Printf Gauge.Measurement Gauge.Monad
                Gauge.ListMap Gauge.Time Gauge.Optional Gauge.CSV Gauge.Format
                Gauge.Source.RUsage Gauge.Source.GC Gauge.Source.Time Paths_gauge
                Statistics.Distribution Statistics.Distribution.Normal
                Statistics.Function Statistics.Internal Statistics.Math.RootFinding
                Statistics.Matrix Statistics.Matrix.Algorithms
                Statistics.Matrix.Mutable Statistics.Matrix.Types
                Statistics.Quantile Statistics.Regression Statistics.Resampling
                Statistics.Resampling.Bootstrap Statistics.Sample
                Statistics.Sample.Histogram Statistics.Sample.Internal
                Statistics.Sample.KernelDensity Statistics.Transform
                Statistics.Types Statistics.Types.Internal System.Random.MWC
                Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
                Numeric.SpecFunctions Numeric.SpecFunctions.Internal Numeric.Sum
abi: fdf8f8cf762677f8c3876110cce6cb6e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gauge-0.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/gauge-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/gauge-0.2.1
hs-libraries: HSgauge-0.2.1-3WbhqotitsoJYtBZKedikn
depends:
    base-4.10.1.0 basement-0.0.6-99d81r6tcUO7TJoRhzEM14 deepseq-1.4.3.0
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA process-1.6.1.0
    directory-1.3.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             basement-0.0.6-99d81r6tcUO7TJoRhzEM14=e1fa2e5153802fe1f40916c736b43137
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
haddock-interfaces: /usr/share/doc/haskell-gauge/html/gauge.haddock
haddock-html: /usr/share/doc/haskell-gauge/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gauge-0.2.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gauge.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gauge
version: 0.2.1
id: gauge-0.2.1-BKhoQClRyhqA0r9X9Pavz0
key: gauge-0.2.1-BKhoQClRyhqA0r9X9Pavz0
license: BSD3
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-gauge
synopsis: small framework for performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Gauge Gauge.Analysis Gauge.Benchmark Gauge.Main Gauge.Main.Options
hidden-modules: Gauge.IO.Printf Gauge.Measurement Gauge.Monad
                Gauge.ListMap Gauge.Time Gauge.Optional Gauge.CSV Gauge.Format
                Gauge.Source.RUsage Gauge.Source.GC Gauge.Source.Time Paths_gauge
                Statistics.Distribution Statistics.Distribution.Normal
                Statistics.Function Statistics.Internal Statistics.Math.RootFinding
                Statistics.Matrix Statistics.Matrix.Algorithms
                Statistics.Matrix.Mutable Statistics.Matrix.Types
                Statistics.Quantile Statistics.Regression Statistics.Resampling
                Statistics.Resampling.Bootstrap Statistics.Sample
                Statistics.Sample.Histogram Statistics.Sample.Internal
                Statistics.Sample.KernelDensity Statistics.Transform
                Statistics.Types Statistics.Types.Internal System.Random.MWC
                Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
                Numeric.SpecFunctions Numeric.SpecFunctions.Internal Numeric.Sum
abi: f764a2a0c5a5b90f5e3dadb7c063329d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gauge-0.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/gauge-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/gauge-0.2.1
hs-libraries: HSgauge-0.2.1-BKhoQClRyhqA0r9X9Pavz0
depends:
    base-4.10.1.0 basement-0.0.7-IRcTCDmYoctGxt4FUYqdQc deepseq-1.4.3.0
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA process-1.6.1.0
    directory-1.3.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             basement-0.0.7-IRcTCDmYoctGxt4FUYqdQc=fbee28466a7ad64c7b9a8e7e271c596e
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
haddock-interfaces: /usr/share/doc/haskell-gauge/html/gauge.haddock
haddock-html: /usr/share/doc/haskell-gauge/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
